
#define NatC1Letters "I"  
#define NatC2Letters "i" 

/*

   NatChCas()  : National Change Case ( Convert UPPER<->LOWER case chars to each other )
               
   Syntax      : NatChCas( <cOneCaseString> [,<lUpper>] ) -> <cOtherCaseString> 
               
   Arguments   : <cOneCaseString> : String to convert
                 <lUpper> : If .T.  (default)  lower to upper, else upper to lower 
                 conversion will be made.
               
   Returns     : <cOtherCaseString> : othercase equivalent of <cOneCaseString>
               
   Required    : NatC1Letters and NatC2Letters constants (or variables) including 
                 national upper and lower letters.
                 
   Coution     : None-letter characters left intact
               
   Category    : Strings

   Description : If contents of NatC1Letters uppercase and NatC2Letters lowercase letters,
                 function works like UPPER(); in reverse order it works like LOWER().
                
                 In other words, always converts NatC1Letters characters to NatC2Letters.  
                 
                 Attention to <lUpper>.
                 
   Author      : Bicahi Esgici ( esgici <at> gmail )
               
   Scope       : Public domain, all rights reserved.
               
   History     : 2011 10 : First release
                 
*/

FUNCTION NatChCas(;                       // National Change Case ( UPPER<->LOWER )
                   cInStr,;   // String to convert
                   lUpper )   // .T. : to upper, .F. : to lower
                   
   LOCAL nStrPtr := 0,;
         cRetVal := '',;
         cSrcChr := ''

   lUpper  := IF( HB_ISNIL( lUpper ), .T., lUpper )      
   
   cRetVal := IF( lUpper, UPPER( cInStr ), LOWER( cInStr ) )  
      
   FOR nStrPtr := 1 TO LEN( NatC2Letters )
     cSrcChr := SUBS( NatC2Letters, nStrPtr,1)
     WHILE cSrcChr $ cRetVal
        cRetVal := STUFF( cRetVal, AT( cSrcChr, cRetVal), 1, SUBS( NatC1Letters, nStrPtr, 1))
     ENDDO
   NEXT nStrPtr 

RETURN cRetVal  // NatChCas()
   
*-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._





